@@ -17,9 +17,6 @@ class TestUtil(TestCase):
     def test_int_to_base64(self):
         self.assertRaises(ValueError, util.int_to_base64, -1)
 
-    def test_json_b64encode(self):
-        self.assertEqual(util.json_b64encode("{}"), b"e30")
-
     def test_urlsafe_b64decode(self):
         self.assertEqual(util.urlsafe_b64decode(b"_foo123-"), b"\xfd\xfa(\xd7m\xfe")
         self.assertRaises(binascii.Error, util.urlsafe_b64decode, b"+foo123/")
